@@ -8,8 +8,9 @@ int main(void) {
 	int fd = mkstemp(filename);
 	unlink(filename);
 
-	lseek(fd, 1023, SEEK_SET);
-	write(fd, filename, 1);
+	count_assert(fd >= 0);
+	count_assert(lseek(fd, 1023, SEEK_SET) == 1023);
+	count_assert(write(fd, filename, 1) == 1);
 
 	count_assert(size_autodetect(fd) == 1024);
 	count_assert(size_autodetect(fd) != 1023);
