@@ -59,7 +59,6 @@ int main(void) {
 	cl.difffile = 0;
 	cl.difffilelen = 0;
 	cl.difmap = NULL;
-	cl.modern = TRUE;
 	cl.transactionlogfd = -1;
 	cl.clientfeats = 0;
 	pthread_mutex_init(&cl.lock, NULL);
@@ -71,10 +70,5 @@ int main(void) {
 	count_assert(g_off == 0);
 	count_assert(g_len == 1024*1024);
 
-	req.from = 1024 * 1024 * 1024;
-	req.len = 1024 * 1024;
-	count_assert(exptrim(&req, &cl) == -1);
-	count_assert(errno == EINVAL);
-
 	return 0;
 }
